@@ -215,7 +215,7 @@ instance FromJSON Issue where
           <*> o .:? "assignee"
           <*> o .: "user"
           <*> o .: "title"
-          <*> o .: "pull_request"
+          <*> o .:? "pull_request"
           <*> o .: "url"
           <*> o .: "created_at"
           <*> o .: "body"
@@ -535,8 +535,7 @@ obj `values` key =
     parseJSON $ Array $ V.fromList $ Map.elems children
 
 -- | Produce the value for the last key by traversing.
-(<.:>) :: (FromJSON v, Monoid v) => Object => [T.Text] -> Parser v
-_obj <.:> [] = pure mempty
+(<.:>) :: (FromJSON v) => Object -> [T.Text] -> Parser v
 obj <.:> [key] = obj .: key
 obj <.:> (key:keys) =
   let (Object nextObj) = findWithDefault (Object Map.empty) key obj in
